#
# spec file for package okteta
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define Kasten_sover 4
%define Okteta_sover 3
%bcond_without released
Name:           okteta
Version:        0.26.20
Release:        1.2
Summary:        Hex Editor
License:        GFDL-1.2-only AND GPL-2.0-only
URL:            https://apps.kde.org/okteta
Source0:        https://download.kde.org/stable/okteta/%{version}/src/okteta-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/okteta/%{version}/src/okteta-%{version}.tar.xz.sig
# https://invent.kde.org/sysadmin/release-keyring/-/blob/master/keys/kossebau@key1.asc?ref_type=heads
Source2:        okteta.keyring
%endif
Source99:       okteta-rpmlintrc
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules >= 5.48.0
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5Bookmarks)
BuildRequires:  cmake(KF5Codecs)
BuildRequires:  cmake(KF5Completion)
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5NewStuff)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5Service)
BuildRequires:  cmake(KF5WidgetsAddons)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qca-qt5)
BuildRequires:  cmake(Qt5Core) >= 5.9.0
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5ScriptTools)
BuildRequires:  cmake(Qt5UiPlugin)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
Obsoletes:      %{name}5 < %{version}
Provides:       %{name}5 = %{version}

%description
Okteta is a hex editor for the raw data of files.

%package data
Summary:        Hex Editor data files
# the files were in the main package before
Conflicts:      %{name} < 0.26
BuildArch:      noarch

%description data
Data files used by Okteta/libKasten, e.g. structures definitions.

%package part
Summary:        Hex Editor KParts plugin
Recommends:     %{name}-part-lang

%description part
Hex editing component for KParts

%package -n libKasten%{Kasten_sover}
Summary:        High-level hex editor/viewer framework libraries
Requires:       %{name}-data
Recommends:     libkasten-lang
Provides:       libkasten = %{version}

%description -n libKasten%{Kasten_sover}
Kasten is a WIP higher-level framework for composable document-centric
applications.

%package -n libOkteta%{Okteta_sover}
Summary:        Hex editor/viewer QWidgets libraries
Recommends:     libokteta-lang
Provides:       libokteta = %{version}

%description -n libOkteta%{Okteta_sover}
Okteta libraries for QWidget-based hex editing widgets.

%package devel
Summary:        Development files for the Okteta Hex Editor
Requires:       libKasten%{Kasten_sover} = %{version}
Requires:       libOkteta%{Okteta_sover} = %{version}
# designer plugin was in the main package before
Conflicts:      %{name} < 0.26
Obsoletes:      %{name}5-devel

%description devel
Contains the development files for the Okteta Hex Editor.

%lang_package
%lang_package -n %{name}-part
%lang_package -n libkasten
%lang_package -n libokteta

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -DBUILD_TERMINALTOOL:BOOL=FALSE

%cmake_build

%install
%kf5_makeinstall -C build

%find_lang okteta
%find_lang oktetapart
%find_lang liboktetacore libokteta.lang
%find_lang liboktetagui libokteta.lang
%find_lang libkasten libkasten.lang
%find_lang liboktetakasten libkasten.lang
%{kf5_find_htmldocs}

%ldconfig_scriptlets -n libKasten%{Kasten_sover}
%ldconfig_scriptlets -n libOkteta%{Okteta_sover}

%files
%license LICENSES/*
%doc %lang(en) %{_kf5_htmldir}/en/okteta/
%{_kf5_applicationsdir}/org.kde.okteta.desktop
%{_kf5_appstreamdir}/org.kde.okteta.appdata.xml
%{_kf5_bindir}/okteta
%{_kf5_iconsdir}/hicolor/*/*/*.*

%files data
%license LICENSES/*
%{_kf5_bindir}/struct2osd
%{_kf5_configkcfgdir}/
%{_kf5_knsrcfilesdir}/okteta-structures.knsrc
%{_kf5_sharedir}/mime/packages/okteta.xml
%{_kf5_sharedir}/okteta/

%files part
%license LICENSES/*
%{_kf5_plugindir}/kf5/
%{_kf5_servicesdir}/oktetapart.desktop

%files -n libKasten%{Kasten_sover}
%license LICENSES/*
%{_kf5_libdir}/libKasten%{Kasten_sover}*.so.*

%files -n libOkteta%{Okteta_sover}
%license LICENSES/*
%{_kf5_libdir}/libOkteta%{Okteta_sover}*.so.*

%files devel
%{_kf5_cmakedir}/
%{_kf5_libdir}/libKasten%{Kasten_sover}*.so
%{_kf5_libdir}/libOkteta%{Okteta_sover}*.so
%{_kf5_prefix}/include/*/
%{_kf5_mkspecsdir}/qt_OktetaCore.pri
%{_kf5_mkspecsdir}/qt_OktetaGui.pri
%{_kf5_libdir}/pkgconfig/OktetaCore.pc
%{_kf5_libdir}/pkgconfig/OktetaGui.pc
%{_kf5_plugindir}/designer/

%files lang -f %{name}.lang

%files part-lang -f oktetapart.lang

%files -n libkasten-lang -f libkasten.lang

%files -n libokteta-lang -f libokteta.lang

%changelog
* Mon Mar  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 0.26.20:
  * Improved: translations
  * Changed: minimum supported CMake version now 3.16, for
    compat with CMake 4.0
* Sun Feb  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 0.26.19
  * Improved: show any on-screen keyboard on click into byte
    array view area
  * Improved: translations
  * Fixed: zoom scaling was broken on setting a font with
    different size (kde#498926)
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
* Thu Oct 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.26.18
  * Added: C code export tool now also with 64-bit integer types
    options
  * Added: print preview dialog
  * Improved: char set conversion substitute byte now changeable
  * Improved: used char set conversion substitute byte is remembered
  * Improved: multiple issues in font-only view zooming
  * new menu action to reset zoom to 100 %%
  * zoom slider got button to reset zoom to 100 %%
  * zoom slider, menu actions, mouse & touch controls zoom
    steps now aligned
  * zoom slider buttons now show tooltips
  * Improved: C code export tool now uses fixed width integer
    types options
  * Improved: "Copy As" dialog on resize has preview stretch
    to available height
  * Improved: "Export" dialog on resize has preview stretch
    to available height
  * Improved: the configured page layout is remembered when printing
  * Fixed: no more zoom state disorder on changing row/column mode
  * Fixed: char set conversion substitute byte updated on char
    coding change
  * Fixed: no more scroll bars flickering on changing row/column mode
  * Fixed: bytes line editors now use escape code
    w/ undefined/unprintable chars
  * Fixed: multiple issues in printing
  * use row layout if used in view
  * use current count of bytes per line in view
  * apply configured page content margins
  * Changed: font zoom range changed to 2 - 96 pt
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.26.17
  * Added: Building the Terminal tool now optional
  * Fixed: initial too large window size (kde#462703)
  * Fixed: leakage of QMimeData objects of byte array file/data
    generation
  * Changed: Statistics tool: use configured undefined char in
    table
  * Changed: Value/Char Table tool: use configured undefined
    char in table
* Fri Aug  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.26.16:
  * Update translations
* Fri Jan  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 0.26.15
  * Improved: translations
  * Improved: Decoding table now supports DnD of data entry
  * Improved: String extraction tool now supports DnD of string
    entry
  * Improved: Structures tool now supports drag of data entry
  * Improved: Statistics tool also adds HTML variant to data
    copy & DnD
  * Improved: Statistics tool now supports DnD of selected
    statistic data
  * Improved: views tab bar now supports changing current tab on
    hovering DnD
  * Improved: Decoding table display numeric values localized
  * Improved: File info now has MIME type & size text
    mouse-selectable/-copyable
  * Fixed: Byte array views had wrong selection background next
    to markers
  * Fixed: Structures tool ignored edits in second half of
    primitive type arrays
  * Fixed: Structures tool missed change update of arrays with
    primitive types
* Wed Dec 13 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.26.14
  * Improved: translations
  * Improved: default docker widgets layout hack updated with a
    Qt 5.15 value
  * Improved: byte array view now supports Delete key also in
    value column/row
  * Fixed: ELF structure definition had wrong e_phoff label
    (kde#474838)
  * Fixed: status bar cursor position & selection display max.
    width calculation
  * Fixed: export of view as text now uses view setting for
    offset encoding
  * Fixed: printing of view now uses view setting for offset
    encoding
  * Changed: ISO-8859-8-I removed from codec set, Qt made
    ISO-8859-8 the same
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.26.13
  * Improved: translations
  * Improved: Decoding table now displays some control chars as
    escaped terms
  * Improved: Decoding table now supports editing some chars as
    escaped terms
  * Improved: Structures tool now feeds some chars as escaped
    terms to editor
  * Improved: CMake Unity builds now possible
  * Fixed: Structures tool stored edited primitive array
    elements on bad offset
  * Fixed: Structures tool now displays chars only as the
    supported 7-bit ASCII
* Fri Jul  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.26.12
  * Improved: translations
  * Improved: Structures tool: show char arrays as string with
    the type entry
  * Fixed: Exporting: no more duplicated overwrite confirmation
    dialog
  * Fixed: Saving: no more duplicated overwrite confirmation
    dialog
* Wed Jun 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 0.26.11:
  * Improved: translations
  * Improved: Search tool: store used settings in the config
  * Improved: Replace tool: store used settings in the config
  * Improved: Select range tool: store used settings in the config
  * Improved: Goto tool: store used settings in the config
  * Improved: Pattern generator: store also used input encoding
    in the config
  * Improved: Statistics tool: add option to copy data to clipboard
  * Improved: Statistics tool: use consistent formatting for
    percent column
  * Improved: Structures tool: enable context menu for array and
    string elements
  * Improved: Structures tool: show tooltip for array & string elements
  * Fixed: Search tool: prevent crash on backward search with empty array
  * Fixed: Search tool: enhance/fix search behaviour with existing selection
  * Fixed: Search tool: don't reset stored search direction on first dialog show
  * Fixed: Replace tool: prevent crash on backward search with empty array
  * Fixed: Replace tool: enhance/fix search behaviour with existing selection
  * Fixed: Structures tool: fix parsing 3 and 4 byte UTF-8 sequences
  * Fixed: Structures tool: fix outdated error indices for UTF-8 string decoding
  * Fixed: unit tests accidentally shared working directories (kde#467541)
  * Changed: Select range tool: move "Relative to end" field next to end input
  * Changed: Search tool: disable automagic for "In selection" checkbox (kde#441925)
  * Changed: Replace tool: disable automagic for "In selection" checkbox (kde#441925)
* Mon Jan 16 2023 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.26.10
  * Improved: translations
  * Improved: Skip bookmark on current position for next/previous
    navigation
- cleanup spec file
* Sun Jun 12 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.26.9
  * Fixed: multiple issues in Structures tool
    + wrong warnings about unknown tag name "enumDef" in <data>
    + missing cleaning of any existing string data on reading zero-bytes string
    (kde#396057)
    + bad condition for string maxBytes value meaning empty string (kde#396057)
    + missing update of tree view after committing a change (kde#337653)
    + wrong offset for view markup of string characters
    + reading data from wrong offset on changes with a locked offset
    + missing combobox editor for enumerations with defined values (kde#337652)
  * Improved: multiple things in Structures tool
    + new context menu to copy data & display string to the clipboard
    (kde#314798)
    + additional action for before-mentioned context menu to select the bytes
  * Improved: control elements in tool views all have margins to the border
    and follow general QToolBar button style
  * Improved: translations
* Tue May 17 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 0.26.8
  * Fixed: Float 32-bit editor in decoding table tool no longer rejects negative
    values & decimal places (kde#453819)
  * Fixed: PNG structure definition example now ensures use of big endianness
    (kde#452362)
  * Improved: translations
  * Improved: have more text vertically centered in lists in tool views
  * Changed: no more use of fixed font type for any list headers in tool views
* Thu Apr 28 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add okteta-rpmlintrc to silence the'shlib-policy-name-error'
  rpmlint error
* Wed Feb 23 2022 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.26.7
  * Improved: translations
  * Fixed: crash in string extraction tool with marked strings from
    closed view (kde#444405)
  * Fixed: in JIS X 0201 codec properly map ASCII control char
    subset
  * Fixed: use own IBM874 codec, given Qt with ICU maps it to
    TIS-620
  * Changed: a context menu now available with the view area (incl.
    tabs)
  * Changed: tabs of views can now be reordered (inside a single
    tab area)
  * Changed: empty documents can be created by LMB double-clicks
    in empty areas
  * Changed: remember used settings of tools across app restarts
  * Changed: remember used settings of data generators across app
    restarts
  * Changed: remember used settings of data encoders across app
    restarts
- Add signature file and keyring
* Sat Apr 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update URL.
* Tue Mar 30 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 0.26.6
  * Improved: translations
  * Changed: touch screen input now handled explicitly, not as
    simulated mouse
    Initial set of support:
    + pinch gesture for zooming
    + tap gesture for setting cursor
    + tap & hold gesture for context menu
    + flick gesture for scrolling
  * Fixed: cursor after replacing inserts always positioned after
    new content
  * Fixed: cursor no longer displays value for 0x20 byte in some
    non-positions
  * Fixed: "Cut" menu entry now disabled in overwrite mode, being
    ignored action
  * Fixed: modification status icons update on app color theme
    change
  * Fixed: current cursor colors updated right after app color
    theme change
* Wed Feb  3 2021 wbauer@tmo.at
- Update to 0.26.5
  * Improved: Structure definitions allow custom pointer
    interpretations in JS
  * Improved: cursor flash time setting of 0 (= no blinking)
    supported
  * Improved: cursor shows char/value in background color instead
    of blank
  * Improved: new menu entry for selecting custom UI color scheme
  * Improved: less deprecated Qt/KF code usage
  * Improved: translations
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Wed Jul 29 2020 wbauer@tmo.at
- Update to 0.26.4
  * Improved: struct2osd uses castxml now (gccxml has been
    deprecated)
  * Improved: less deprecated Qt code usage, avoiding logged
    runtime warnings
  * Improved: translations
* Mon Feb  3 2020 wbauer@tmo.at
- Update to 0.26.3
  * Added: CRC-64 algorithm for the checksum tool
  * Improved: install knsrc file at new location with newer KF5
    versions
  * Improved: use more latest Qt API where possible
  * Improved: translations
  * Fixed: view profile managing dialog now properly sized default
    marker column
  * Fixed: store.kde.org access for structure definitions also
    works without Plasma being installed
* Tue Jul  2 2019 wbauer@tmo.at
- Update to 0.26.2
  * Fixed: replacing content backwards no longer skips some content
  * Fixed: "From Cursor" in search dialog now disabled with "In
    Selection" on
  * Fixed: "In Selection" disabled now if there is nothing selected
  * Fixed: search dialog now modal to prevent unsupported
    interaction with app
  * Improved: maximum array size in structures extended to 64K
    (kde#371790)
  * Translations improved (ko)
* Thu Apr 11 2019 wbauer@tmo.at
- Update to 0.26.1
  * Fixed: bad offset of elements in statusbar
  * Translations improved (cs, en_GB, ga, lv, nn, pt)
* Tue Mar 12 2019 wbauer@tmo.at
- Update to 0.26.0
  * New: context menu available in byte array views, in the
    program, in the KParts plugin and and in the hex editing
    widgets from LibOktetaGui
  * New: qmake pri files and pkg-config pc files installed for the
    OktetaCore & OktetaGui libraries (_not_ for any Kasten ones)
  * Changed: ABI-breaking and software-incompatible clean-up of API
    and installed headers of the Okteta & Kasten libraries
  * Fixed: the metadata desktop file for the KParts plugin
    oktetapart is installed again, so it can be found and selected
    as viewer via its metadata
- Split out the libs and KParts plugin to separate packages as
  upstream recommends, move designer plugin to the devel package
* Mon Dec 31 2018 wbauer@tmo.at
- Update to 0.25.5
  * Add option to disable build of KParts plugin, Kasten libs, or
    program
  * Translations improved (fi, id, ru, zh_CN)
* Mon Oct  8 2018 wbauer@tmo.at
- Update to 0.25.4
  * Fix blurry cursor pixmaps in HiDPI
  * Fix broken shadow cursor in HIDPI
  * Translations improved (ru, sk)
* Mon Sep  3 2018 wbauer@tmo.at
- Update to 0.25.3
  * Setting Qt::AA_EnableHighDpiScaling for proper HiDPI scaling in
    environments where none of the QT_*SCALE* vars is set
  * Translations improved (ko, nn)
* Wed Aug  8 2018 wbauer@tmo.at
- Update to 0.25.2
  * Hide broken "Show non-printable chars" feature in UI for now
  * Translations improved (fi, pt_BR)
* Fri Jul 13 2018 wbauer@tmo.at
- Update to 0.25.1
  * Remove extra margins from config dialog pages of the Structures
    tool
  * Remove debug log "register count: %%d, destroy count %%d:" from
    normal build
  * Translations improved (id, it, nn, zh_CN)
* Tue Jun 12 2018 wbauer@tmo.at
- Update to 0.25.0
  * First stand-alone release independent of KDE Applications
- Changes since 0.24.3 (as part of KDE Applications 17.12.3):
  * Support for opening files by Drag'n'Drop on the empty
    background and the empty view tab bar space has been restored
    (lost in Qt5 port)
  * Closing documents per MMB on the tab has been restored (lost in
    Qt5 port)
  * Mass reformatting & modernization of source code
- Update build requirements and file list
- Update URL and Source URL
- Mark license files with %%license instead of %%doc
- Ran spec-cleaner
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Use QStyle::SP_DialogCloseButton instead of hardcoding "dialog-close"
  * Use icons with more BookmarksController actions
  * Bump version to 0.24.3
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Bump version to 0.24.2
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Fix StringDataInformation::setEncoding() logic on UTF16 endianess change
  * Fix crash on shutdown due to mTerminalPart trying to recover (kde#384993)
  * Bump version to 0.24.1
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * appdata: use the more generic URL for documentation
  * Bump version to 0.24.0
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Bump version to 0.23.90
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Bump version to 0.23.80
  * New name for designer plugin file: oktetawidgets, following a pattern
  * Don't use KConfigDialogManager::changedMap with newer KF
  * No need to override KStandardAction::close icon >=KF5.38
  * Use newer version of QUrl::fromUserInput, drop QRegExp hack
  * No longer export private classes of AbstractFileSystem*Jobs
  * More const ref
  * Use QStringLiteral
  * Mpre QVector::reserve usage
  * More const ref for passing complex types
  * Use "override" tag also in DATAINFORMATION_CLONE_DECL macro
  * Merge test value codec metadata in one table
  * Use "override" tag for overriding methods
  * Use nullptr
  * Explicitely set copy constructors to be default implementation
  * Remove wrong "return" statement in void method
  * Remove bogus "emit" statements
  * More const ref for passing complex types
  * Use more QList/QVector::reserve
  * Use QStringLiteral
  * Remove unused variable
  * Use midRef where possible
  * Change Q_ENUMS -> Q_ENUM
  * Port to function pointer based Qt signal/slot connects
  * Bump min dep version of ECM/KF to 5.18
  * Bump min dep version of Qt to 5.6
  * Bump version to 0.23.60
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Bump version to 0.23.3
  * Structures settings: Fix defunct structure plugin enabling/disabling
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Add app=okteta to donation url in appdata
  * Use edit-delete icon for "delete view profile" action, shred is too much
  * Bump version to 0.23.2
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Bump version to 0.23.1
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Use edit-delete-shred icon for "delete view profile" action
  * Use document-close icon for document close actions
  * Don't abuse #pragma message for TODOs which are not critical
  * Remove unneeded wrapper widget in structures settings dialog
  * Bump version to 0.22.90
  * Add missing added/closing signal forwarding in document strategies
  * Use function-adress slot connect in SingleDocumentStrategy
  * Remove extra compile options, stick to what KDECompilerSettings sets
  * Bump version to 0.22.80
  * Use KCrash
  * Bump version to 0.22.60
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.07.90.php
* Mon Jul 24 2017 jengelh@inai.de
- Make description neutral again
* Sun Jul 16 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Qt5Designer_VERSION_STRING was deprecated in 5.1, use Qt5Designer_VERSION
  * Add gcc-compatible fallthrough comment
  * Add missing break;
  * Bump version to 0.22.3
  * Extend AbstractByteArrayModelIfTest::testFill to test filling past end
  * Make empty filling a noop for FixedSizeByteArrayModel
  * Fix filling across the end in PieceTableByteArrayModel & ByteArrayModel
* Tue Jul 11 2017 fabian@ritter-vogt.de
- Improve description text (boo#1047988)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Bump version to 0.22.2
  * Use explicit constructor call for QFlags-based types instead of blank 0
  * Use Qt::NoItemFlags instead of blank 0
  * Only register to D-Bus after inital commandline parsing has been done
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Bump version to 0.22.1
  * Default to no debug logging in Okteta & Kasten libs for Qt >= 5.5
  * Default to no debug logging in Okteta app
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Fix doctype of ui.rc files to match root element
  * Bump version to 0.22.0
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Use non-deprecated ECM KDEInstallDirs variables
  * Change deprecated <kpartgui> to <gui>
  * Add QT_DEPRECATED_WARNINGS/QT_DISABLE_DEPRECATED_BEFORE
  * Port qSort -> std::sort
  * Bump version to 0.21.90
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.03.80.php
- Changes since 16.12.3:
  * For compared or concatenated strings use QLatin1String, not QStringLiteral
  * Do not use static QString objects
  * Add missing emit keyword on signal call
  * Compose string manually
  * Remove unused variables/instances
  * Avoid calling methods on a temporary object
  * Add missing Q_OBJECT macro to QObject subclasses
  * Do not exit application if KDBusService fails to initialize.
  * Fix typo in docs
  * fix wrong structures directory
  * replace kf5-config from kdelibs4support with qtpaths
  * Point to category page on store.kde.org in docs
  * Replace kde-files.org with store.kde.org in docs
  * Bump version to 0.21.60
* Sat Mar 25 2017 fabian@ritter-vogt.de
- Add BuildRequires: cmake(Qca-qt5)
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.07.90.php
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Tue Jun 14 2016 wbauer@tmo.at
- Use shared-mime-info macros (boo#979301)
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.07.90.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Wed Dec  3 2014 tittiatcoke@gmail.com
  Update to KDE Applications 14.11.97
  * KDE Applications 14.12 Release Candidate
  * See http://www.kde.org/announcements/announce-applications-14.12-rc.php
  * Okteta is now KDE Frameworks based
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Tue Aug 12 2014 hrvoje.senjan@gmail.com
- Use kde4-macros for filelists, okteta uses kdelibs4 buildsystem
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Sat May  3 2014 hrvoje.senjan@gmail.com
- Added libqca2-devel BuildRequires, needed for algorithms of the
  checksum tool
- Remove ancient Obsoletes/provides
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sun Nov 10 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Wed Jul  3 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
  * Split off from kdesdk4
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Fri Apr 12 2013 tittiatcoke@gmail.com
- Updated Licenses for the packages (bnc#814081)
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * see http://www.kde.org/announcements/announce-4.10-beta1.php
  * Umbrello:  Line based diagram grid
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Sat Aug  4 2012 ctrippe@opensuse.org
- fix lokalize issue with startup with project file (bnc#774072,
  kde#300810)
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Mon Apr  9 2012 ctrippe@opensuse.org
- lokalize requires kross-python for scripts (bnc#754576)
* Sun Apr  1 2012 wstephenson@suse.com
- Fix broken permissions problem in script
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Fri Jan 27 2012 tchvatal@suse.cz
- Add patch for lokalize fixing upstream bug #292575
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Sat Dec  3 2011 rwooninck@opensuse.org
- Add libtool as BuildRequires to build kstartperf
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Wed Nov 30 2011 idoenmez@suse.de
- Fix build with Qt 4.8
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Fri Oct  7 2011 coolo@suse.com
- buildrequire specific kdelibs4
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Fri Sep 23 2011 idonmez@suse.com
- lokalize should depend on kdesdk4-strigi now that kdesdk4 base
  package is gone.
* Sat Sep 17 2011 toddrme2178@gmail.com
- Split kompare-devel package (fix for RPMLINT warning)
- Split kprofilemethod package  (fix for RPMLINT warning)
- Split strigi package  (fix for RPMLINT warning)
- Fixed kde4-l10n-devel group (fix for RPMLINT warning)
- Capitalized dolphin-plugins summary (fix for RPMLINT warning)
- Fixed okteta self-obsoletes (fix for RPMLINT warning)
- Removed duplicate files (fix for RPMLINT warning)
- Removed empty base package  (fix for RPMLINT warning)
- Added base package obsoletes/provides to strigi package
- Cleaned up spec file formatting
* Thu Sep  8 2011 andrea.turrini@gmail.com
- fixed typos in descriptions of kdesdk4.spec
* Fri Sep  2 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Thu Jul 21 2011 idonmez@novell.com
- Update to 4.6.95
* Fri Jul  1 2011 dmueller@suse.de
- update to 4.6.5
  * Bugfixes over KDE 4.6.5
  * see http://kde.org/announcements/changelogs/changelog4_6_4to4_6_5.php for details
* Fri Jun  3 2011 dmueller@suse.de
- update to 4.6.4
  * Bugfixes over KDE 4.6.3
  * see http://kde.org/announcements/changelogs/changelog4_6_3to4_6_4.php for details
* Thu Apr 28 2011 dmueller@suse.de
- update to 4.6.3
  * Bugfixes over KDE 4.6.2
  * see http://kde.org/announcements/changelogs/changelog4_6_2to4_6_3.php for details
* Fri Apr  1 2011 dmueller@suse.de
- update to 4.6.2
  * Bugfixes over KDE 4.6.1
  * see http://kde.org/announcements/changelogs/changelog4_6_1to4_6_2.php for details
* Tue Mar  8 2011 dmueller@suse.de
- update to 4.6.1
  * Bugfixes over KDE 4.6.0
  * see http://kde.org/announcements/changelogs/changelog4_6_0to4_6_1.php for details
* Thu Feb 17 2011 wstephenson@novell.com
- call update-mime-database in pre/post install scripts
* Wed Jan 19 2011 dmueller@suse.de
- update to 4.6.0
  * For highlights, see http://kde.org/announcements/4.6
* Wed Jan 12 2011 ctrippe@gmx.net
- Build okteta-devel which is required for the okteta kdevelop-plugin
  (bnc#656174)
* Tue Jan 11 2011 ctrippe@gmx.net
- BuildRequire binutils-devel to build kmtrace (bnc#663361)
* Tue Jan  4 2011 dmueller@suse.de
- update to 4.5.95
  * KDE 4.6 RC2
  * no upstream changelog available.
* Wed Dec 22 2010 dmueller@suse.de
- update to 4.5.90
  * KDE 4.6 RC1
  * no upstream changelog available.
* Wed Dec  8 2010 toddrme2178@gmail.com
- Add optional dependency
  * QCA2 -- Needed for most of the algorithms of the checksum tool in Okteta.
- Removed build tests for unsupported openSUSE versions (11.0 and earlier)
* Fri Dec  3 2010 dmueller@suse.de
- update to 4.5.85
  * KDE 4.6 Beta2
  * Final Beta before RC, various fixes from Beta1
  * no upstream changelog available.
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
  * KBugBuster was dropped because it was broken and unmaintained
* Thu Nov 11 2010 coolo@novell.com
- fix file list
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Sun Aug 29 2010 tittiatcoke@gmail.com
- Added additional build requirement for Antlr package. This will
  now allow the build of the po2xml binary (bnc#630625)
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80 (KDE 4.4 Beta1):
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: icon fixes and translation updates
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Sun Aug 23 2009 tittiatcoke@gmail.com
- Added a patch to enable build by resolving two
    void-return-in-non-void-function errors
* Thu Aug 20 2009 beineri@opensuse.org
- kompare is no real VCS, don't have Development/ in default install
* Fri Jul 31 2009 llunak@suse.cz
- suggest ctags for kate (bnc#527074)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Thu Jul  9 2009 dmueller@suse.de
- update to 4.2.96
* Thu Jul  2 2009 beineri@opensuse.org
- make lokalize require python-kde4 (bnc#517869)
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Feb 19 2009 dmueller@suse.de
- update branch diff
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Fri Jan 16 2009 dmueller@suse.de
- remove unnecessary patch
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 dmueller@suse.de
- libical-devel isalready included by kdepimlibs-devel
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Sat Nov 29 2008 stbinner@suse.de
- fix build after removal of libical copy from kdepimlibs
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Wed Aug 13 2008 dmueller@suse.de
- branch diff update
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Fri Jul 18 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Thu Jul  3 2008 dmueller@suse.de
- update to 4.0.85
* Mon Jun 30 2008 dmueller@suse.de
- add directory ownerships
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Sat Jun 14 2008 schwab@suse.de
- Use -mminimal-toc on ppc64.
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Mon Apr 21 2008 dmueller@suse.de
- branch diff update
  * fix time parsing in cervisia
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Sat Dec  8 2007 dmueller@suse.de
- update to 3.97.0
* Sat Dec  8 2007 stbinner@suse.de
- fix build
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Wed Oct 31 2007 dmueller@suse.de
- update to KDE 4.0 Beta4
* Sat Oct 20 2007 dmueller@suse.de
- update to 3.94.1
* Thu Oct 11 2007 dmueller@suse.de
- udpate to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720133
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712063
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703915
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700768
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
- fix file conflict
* Tue Aug  7 2007 stbinner@suse.de
- fix build after strigi update
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685971
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679147
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Thu May 24 2007 stbinner@suse.de
- initial package in abuild
